#! /usr/bin/env python
# -*- coding: utf-8 -*-
from moviepy.editor import VideoFileClip, concatenate

import random

import re # module for regular expressions

def convert_time(timestring):
    """ Converts a string into seconds """
    nums = map(float, re.findall(r'\d+', timestring))
    return 3600*nums[0] + 60*nums[1] + nums[2] + nums[3]/1000

with open("../../video/1.srt") as f:
    lines = f.readlines()

times_texts = []
current_times , current_text = None, ""
for line in lines:
    times = re.findall("[0-9]*:[0-9]*:[0-9]*,[0-9]*", line)
    if times != []:
        current_times = map(convert_time, times)
    elif line == '\n':
        times_texts.append((current_times, current_text))
        current_times, current_text = None, ""
    elif current_times is not None:
        current_text = current_text + line.replace("\n"," ")

def find_word(word, padding=.2):
    """ Finds all 'exact' (t_start, t_end) for a word """
    matches = [re.search(word, text)
               for (t,text) in times_texts]
    return [(t1 + m.start()*(t2-t1)/len(text) - padding,
             t1 + m.end()*(t2-t1)/len(text) + padding)
             for m,((t1,t2),text) in zip(matches, times_texts)
             if (m is not None)]

def assemble_cuts(cuts, outputfile):
    """ Concatenate cuts and generate a video file. """
    final = concatenate([video.subclip(start, end)
                         for (start,end) in cuts])
    final.to_videofile(outputfile)

sentence = "Dignity, each of us matters. And when -- here in the business of their political leaders. In fact, it's been interesting when you see a friend of yours, a classmate, one of the big international food processors, to make doing business easier will have an alternative. But how can that be a leader. All right, how much more interested in the world. Between now and the health of our allies -- including Tanya’s daughter, Sanaa. There’s Sanaa, right Dr."

cuts = []

for word in sentence.split():
    sub_cuts = find_word(word)
    
    if len(sub_cuts) > 0:
        cuts.append(random.choice(sub_cuts))

video = VideoFileClip("../../video/1.mp4")
assemble_cuts( cuts , "../../video/?.mp4")